👨‍💻 Command Line Interface - ngff-zarr
Description: ngff-zarr provides a command line interface to convert a variety of scientific file formats to ome-zarr and inspect and ome-zarr store’s contents. Installation: To install the command line interfac...

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# 👨‍💻 Command Line Interface

`ngff-zarr` provides a command line interface to convert a variety of scientific file formats to ome-zarr and inspect and ome-zarr store’s contents.

## Installation

To install the command line interface (CLI):

    pip install 'ngff-zarr[cli]'

## Usage

### Convert an image file

Convert any scientific image file format supported by either itk, tifffile, or imageio.

Example:

    ngff-zarr -i ./MR-head.nrrd -o ./MR-head.ome.zarr

### Convert an image volume slice series

Note the quotes:

    ngff-zarr -i "series/*.tif" -o ome-ngff.ome.zarr

### Print information about generated multiscales

To print information about the input, omit the output argument.

    ngff-zarr -i ./MR-head.nrrd

### Specify output chunks

    ngff-zarr -c 64 -i ./MR-head.nrrd

### Specify metadata

    ngff-zarr --dims "z" "y" "x" --scale x 1.4 y 1.4 z 2.5 --translation x 6.24 y 360.0 z 332.5 --name LIDC2 -i "series/*.tif"

### Limit memory consumption

Limit memory consumption by passing a rough memory limit in human-readable units, e.g. 8GB with the `--memory-target` option.

    ngff-zarr --memory-target 50M -i ./LIDCFull.vtk -o ./LIDCFull.ome.zarr

### More options

    ngff-zarr --help